#
# spec file for package libcdr
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libcdr-0_1-1
Name:           libcdr
Version:        0.1.7
Release:        1.20
Summary:        Library for parsing the Corel Draw file format structure
License:        MPL-2.0
Group:          Productivity/Publishing/Word
URL:            http://www.freedesktop.org/wiki/Software/libcdr
Source0:        http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
libcdr is a library and a set of tools for reading and converting
binary files produced by Corel Draw.

%package -n %{libname}
Summary:        Library for parsing the Corel Draw file format structure
Group:          System/Libraries

%description -n %{libname}
libcdr is a library for parsing the Corel Draw file format structure.

%package devel
Summary:        Files for Developing with libcdr
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libcdr is a library for parsing the Corel Draw file format structure.

This package contains the libcdr development files.

%package devel-doc
Summary:        Documentation for the libcdr API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libcdr API.

%package tools
Summary:        Tools to work with documents in Corel Draw file format
Group:          Productivity/Publishing/Word

%description tools
Tools to work with documents in Corel Draw file format.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
    --disable-werror \
    --disable-static \
    --docdir=%{_docdir}/%{name} \
    --disable-silent-rules
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -p AUTHORS COPYING.* ChangeLog %{buildroot}%{_docdir}/%{name}

%fdupes -s %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/libcdr*.pc
%{_includedir}/libcdr-*

%files devel-doc
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/html

%files tools
%{_bindir}/*
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/[A-Z]*

%changelog
* Fri Mar 26 2021 Fridrich Strba <fstrba@suse.com>
- Version update to 0.1.7
  * Extend support to the newest CDR format versions
    + Supports currently CDR1 to 23, which is all released versions
    to date.
  * Improve conversion of paragraph text in versions 5 to 23
  * Improve conversion of text on path for versions 6 to 15
- Removed patches:
  * icu-68.patch
    + Integrated upstream
  * libcdr-0.1.1-pkgconfig.patch
    + This was a workaround for SLE11 build failures, not needed
    any more
* Mon Dec 14 2020 Callum Farmer <gmbr3@opensuse.org>
- Add icu-68.patch: fix build with ICU 68
* Sun Feb  2 2020 Fridrich Strba <fstrba@suse.com>
- Version update to 0.1.6
  * Extend support to the newest CDR format versions
    + Supports currently CDR 1 to 21, which is all released
    versions to date
* Mon Oct  2 2017 jengelh@inai.de
- Trim build characteristics from description.
* Mon Oct  2 2017 tchvatal@suse.com
- Version update to 0.1.4:
  * Fix several issues found by oss-fuzz.
  * Require C++11 for build.
  * Fix issues found by coverity.
  * Various code cleanups.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Aug  1 2016 tchvatal@suse.com
- Disable silent rules
- Remove sle11 support code
* Thu Jul 21 2016 fstrba@suse.com
- Upgrade to upstream version 0.1.3
  * Improvements for CMX parsers
  - More robust parsing using the pointers from CMX header
  - Implement almost all fills
  - Implement outline properties
  - Implement embedded raster images
  - Implement transparency lens for fills
  * Some fixes for CDR parsers
  - Consider fill/outline styles
  * Tools
  - Make cmx2* and cdr2* tools handle both CDR and CMX
* Sat Dec 26 2015 fstrba@suse.com
- Upgrade to updstream version 0.1.2
  * Fix various crashes and hangs when reading broken files found
    with the help of american-fuzzy-lop.
  * Fix build with boost 1.59. (rhbz#1258127)
  * Fix various problems detected by Coverity.
  * Do not drop empty text lines. (tdf#67873)
  * Make --help output of all command line tools more
    help2man-friendly.
  * Several other small improvements.
* Wed Nov 11 2015 idonmez@suse.com
- Fix compilation with boost 1.59
* Fri Nov 28 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.1
  * Fix several problems found by Coverity.
  * Fix crash when NULL is passed as input stream.
  * Fix various crashes and hangs when reading broken files found
    with the help of american-fuzzy-lop.
  * Only export public symbols on Linux.
- Remove patch: libcdr-0.1.0-pkgconfig.patch
- Add patch: libcdr-0.1.1-pkgconfig.patch
  * Rediff to apply to current context
* Fri Jul 25 2014 fstrba@suse.com
- Added patch: libcdr-0.1.0-pkgconfig.patch
  * Remove the Requires.private which breaks SLE11 builds
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.0
  * ABI change
  * Remove dependency on libwpd-devel and libwpg-devel
  * Add dependency on librevenge-devel
* Thu Apr 10 2014 fstrba@suse.com
- Update to upstream version 0.0.16
  * Brownbag release
  * Upstream relicensing to MPL-2.0
* Thu Apr 10 2014 fstrba@suse.com
- Fix mistake in licensing
  * 0.0.x line is still tripple LGPL-2.0+ or GPL-2.0+ or MPL-1.1
* Tue Apr  8 2014 fstrba@suse.com
- Update to upstream version 0.0.15
  * Approximation of splines by cubic beziers
  * Support CorelDraw x7 file-format
  * Add a palette #0x03 for spot colours (0x19)
  * first iteration of YIQ255 support
  * hard-depend on libwpd >= 0.9.5
  * settle license on MPL-2.0
- Removed unneeded patches:
  * libcdr-0.0.14-pkgconfig.patch
  * libcdr-0.0.14-wpx_seek_end.patch
* Sat Jan 25 2014 tchvatal@suse.com
- Format with spec-cleaner and noarch documentation.
* Sat Jan 18 2014 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden, saving around 300
  entries in the exported symbol table.
- build with --disable-werror, there are no warnings but werror
  during deployment is undesirable.
* Fri Nov  1 2013 tchvatal@suse.com
- Remove conditionals for docs and use verbose build.
* Tue Oct  8 2013 fstrba@suse.com
- liblcms2 and zlib are compile-time dependencies only
  * Add patch to remove the requirements from *.pc file
* Fri Jul 26 2013 fstrba@suse.com
- Performance regression fix
  * Add patch to unconditionally use WPX_SEEK_END
  * Depend on libwpd-devel >= 0.9.5 that has WPX_SEEK_END
* Mon May 27 2013 fridrich.strba@suse.com
- Update to upstream version 0.0.14
  * Miscellaneous coverity fixes
  * Be more gracious with broken documents
  * Change source code layout in order to allow including
    of headers from the tarball directly.
  * Fix issues with angle units
* Mon Apr 22 2013 fridrich.strba@suse.com
- Update to upstream version 0.0.13
  * Extend text support to CDR versions 5 and 6
  * Fix text parser for CDR version 13+
  * Parse text format strings in CDR version 16
  * Text colour support for CDR versions 5 - 16
  * Add dependency on boost for both json property string
    parser and for extraction of colour information
- Added build dependency on boost-devel
* Mon Apr  8 2013 fridrich.strba@suse.com
- Update to upstream version 0.0.12
  * rewrite of ellitical arc transforms, fixes a fdo#62538
  * multiple fixes for text encondings
  * added cdr2text and cmx2text tools in order to make string
    encoding debugging easier
- Removed upstreamed patch
* Fri Mar  1 2013 fridrich.strba@suse.com
- Update to upstream version 0.0.11
  * Fix positions of circles and their transformations
  * Fix issues with large angle when the angles are negative
  * Implement reading of multi-paragraph text
  * Fix tranformation of bitmaps
  * Miscellaneous coverity fixes
  * Miscellaneous fixes of the SVG generator
- Upstream patch for text encoding overrides in styles
* Fri Jan 25 2013 fridrich.strba@suse.com
- Update to upstream version 0.0.10
  * Fix wrong encoding of some text strings
  * New dependency on libicu-devel
- Upstream patch fixing large-angle computation
* Tue Nov 13 2012 cfarrell@suse.com
- license update: LGPL-2.0+ or GPL-2.0+ or MPL-1.1
  Use either ^or^ or ^and^ to specify a license aggregation or compilation.
  Semicolons and colons are ambigous and confusing
* Mon Nov  5 2012 fridrich.strba@suse.com
- Update to upstream version 0.0.9
  * Fix wrong positions of grouped objects in newer
    CorelDraw file-formats
* Mon Jun 11 2012 jengelh@inai.de
- SPDX license field
* Mon Jun 11 2012 fridrich.strba@suse.com
- Update to upstream version 0.0.8
  * initial text support
- Remove upstreamed patch
* Fri Apr 27 2012 fridrich.strba@suse.com
- Initial package of libcdr
